@@ -1,4 +1,23 @@
-#' Create a pointblank agent object
+#
+#                _         _    _      _                _    
+#               (_)       | |  | |    | |              | |   
+#  _ __    ___   _  _ __  | |_ | |__  | |  __ _  _ __  | | __
+# | '_ \  / _ \ | || '_ \ | __|| '_ \ | | / _` || '_ \ | |/ /
+# | |_) || (_) || || | | || |_ | |_) || || (_| || | | ||   < 
+# | .__/  \___/ |_||_| |_| \__||_.__/ |_| \__,_||_| |_||_|\_\
+# | |                                                        
+# |_|                                                        
+# 
+# This file is part of the 'rich-iannone/pointblank' package.
+# 
+# (c) Richard Iannone <riannone@me.com>
+# 
+# For full copyright and license information, please look at
+# https://rich-iannone.github.io/pointblank/LICENSE.html
+#
+
+
+#' Create a **pointblank** *agent* object
 #'
 #' @description
 #' The `create_agent()` function creates an *agent* object, which is used in a
@@ -37,32 +56,47 @@
 #'   object, or a `tbl_spark` object. Alternatively, a function can be used to
 #'   read in the input data table with the `read_fn` argument (in which case,
 #'   `tbl` can be `NULL`).
-#' @param read_fn A function that's used for reading in the data. If a `tbl` is
-#'   not provided, then this function will be invoked. However, if both a `tbl`
-#'   *and* a `read_fn` is specified, then the supplied `tbl` will take priority.
-#'   There are two ways to specify a `read_fn`: (1) using a function (e.g., 
-#'   `function() { <table reading code> }`) or, (2) with an R formula expression
-#'   (e.g., `~ { <table reading code> }`).
-#' @param name An optional name for the validation plan that the agent will
-#'   eventually carry out during the interrogation process. If no value is
-#'   provided, a name will be generated based on the current system time.
-#' @param actions A list containing threshold levels so that all validation
-#'   steps can react accordingly when exceeding the set levels. This is to be
-#'   created with the [action_levels()] helper function. Should an action levels
-#'   list be used for specific validation step, any default set here will be
-#'   overridden.
-#' @param end_fns A list of functions that should be performed at the end of an
-#'   interrogation.
+#' @param read_fn A function that's used for reading in the data. Even if a
+#'   `tbl` is provided, this function will be invoked to obtain the data (i.e.,
+#'   the `read_fn` takes priority). There are two ways to specify a `read_fn`:
+#'   (1) using a function (e.g., `function() { <table reading code> }`) or, (2)
+#'   with an R formula expression (e.g., `~ { <table reading code> }`).
+#' @param tbl_name A optional name to assign to the input table object. If no
+#'   value is provided, a name will be generated based on whatever information
+#'   is available. This table name will be displayed in the header area of the
+#'   agent report generated by printing the *agent* or calling
+#'   [get_agent_report()].
+#' @param label An optional label for the validation plan. If no value is
+#'   provided, a label will be generated based on the current system time.
+#'   Markdown can be used here to make the label more visually appealing (it
+#'   will appear in the header area of the agent report).
+#' @param actions A option to include a list with threshold levels so that all
+#'   validation steps can react accordingly when exceeding the set levels. This
+#'   is to be created with the [action_levels()] helper function. Should an
+#'   action levels list be used for a specific validation step, the default set
+#'   specified here will be overridden.
+#' @param end_fns A list of function calls that should be performed at the end
+#'   of an interrogation. Each function call should be in the form of a
+#'   one-sided R formula expression, so overall this construction should be
+#'   used: `end_fns = list(~ <R statements>, ~ <R statements>, ...)`. An example
+#'   of a function that can be sensibly used here is [email_blast()], where an
+#'   email of the validation report is generated and sent based on sending
+#'   condition.
 #' @param embed_report An option to embed a **gt**-based validation report into
 #'   the `ptblank_agent` object. If `FALSE` (the default) then the table object
 #'   will be not generated and available with the *agent* upon returning from
 #'   the interrogation.
-#' @param reporting_lang The language to use for automatic creation of briefs
-#'   (short descriptions for each validation step) and for the *agent report* (a
+#' @param lang The language to use for automatic creation of briefs (short
+#'   descriptions for each validation step) and for the *agent report* (a
 #'   summary table that provides the validation plan and the results from the
 #'   interrogation. By default, `NULL` will create English (`"en"`) text. Other
-#'   options include French (`"fr"`), German (`"de"`), Italian (`"it"`), and
-#'   Spanish (`"es"`).
+#'   options include French (`"fr"`), German (`"de"`), Italian (`"it"`), Spanish
+#'   (`"es"`), Portuguese, (`"pt"`), Chinese (`"zh"`), and Russian (`"ru"`).
+#' @param locale An optional locale ID to use for formatting values in the
+#'   *agent report* summary table according the locale's rules. Examples include
+#'   `"en_US"` for English (United States) and `"fr_FR"` for French (France);
+#'   more simply, this can be a language identifier without a country
+#'   designation, like "es" for Spanish (Spain, same as `"es_ES"`).
 #'   
 #' @return A `ptblank_agent` object.
 #'   
@@ -94,8 +128,8 @@
 #' # make the reporting a bit more useful
 #' agent <- 
 #'   create_agent(
-#'     small_table,
-#'     name = "example",
+#'     read_fn = ~ small_table,
+#'     label = "An example.",
 #'     actions = al
 #'   )
 #'
@@ -164,6 +198,9 @@
 #' # slightly different structure; see
 #' # `help(get_agent_x_list)` for more info
 #' # get_agent_x_list(agent)
+#' 
+#' @section Figures:
+#' \if{html}{\figure{man_create_agent_1.png}{options: width=100\%}}
 #'  
 #' @family Planning and Prep
 #' @section Function ID:
@@ -172,19 +209,22 @@
 #' @export
 create_agent <- function(tbl = NULL,
                          read_fn = NULL,
-                         name = NULL,
+                         tbl_name = NULL,
+                         label = NULL,
                          actions = NULL,
                          end_fns = NULL,
                          embed_report = FALSE,
-                         reporting_lang = NULL) {
+                         lang = NULL,
+                         locale = NULL) {
+
+  # Generate a label if none provided
+  label <- generate_label(label = label)
 
-  # Generate an agent name if none provided
-  if (is.null(name)) {
-    name <- paste0("agent_", gsub(" ", "_", Sys.time() %>% as.character()))
-  }
-  
   # Normalize the reporting language identifier and stop if necessary
-  reporting_lang <- normalize_reporting_language(reporting_lang)
+  lang <- normalize_reporting_language(lang)
+  
+  # Set the `locale` to the `lang` value if `locale` isn't set
+  if (is.null(locale)) locale <- lang
 
   # If nothing is provided for either `tbl` or `read_fn`,
   # this function needs to be stopped
@@ -199,22 +239,36 @@ create_agent <- function(tbl = NULL,
     )
   }
   
-  if (!is.null(tbl)) {
+  # Try to infer the table name if one isn't
+  # explicitly given in `tbl_name`
+  if (!is.null(tbl) && is.null(tbl_name)) {
     tbl_name <- deparse(match.call()$tbl)
     if (tbl_name == ".") {
-      tbl_name <- "table"
+      tbl_name <- NA_character_
     }
-  } else {
-    tbl_name <- "table"
+  } 
+  if (is.null(tbl_name)) {
+    tbl_name <- NA_character_
   }
   
-  
-  if (!is.null(read_fn) && is.null(tbl)) {
+  # Prefer reading a table from a `read_fn` if it's available
+  # TODO: Verify that the table is a table object
+  # and provide an error if it isn't
+  if (!is.null(read_fn)) {
+    
     if (inherits(read_fn, "function")) {
+      
       tbl <- rlang::exec(read_fn)
+      
     } else if (rlang::is_formula(read_fn)) {
-      tbl <- read_fn %>% rlang::f_rhs() %>% rlang::eval_tidy()
+      
+      tbl <- 
+        read_fn %>% 
+        rlang::f_rhs() %>% 
+        rlang::eval_tidy(env = caller_env(n = 1))
+      
     } else {
+      
       stop(
         "The `read_fn` object must be a function or an R formula.\n",
         "* A function can be made with `function()` {<table reading code>}.\n",
@@ -237,11 +291,10 @@ create_agent <- function(tbl = NULL,
   # Create the agent list object
   agent <-
     list(
-      name = name,
-      time = as.POSIXct(NA)[-1],
       tbl = tbl,
       read_fn = read_fn,
       tbl_name = tbl_name,
+      label = label,
       db_tbl_name = tbl_information$db_tbl_name,
       tbl_src = tbl_information$tbl_src,
       tbl_src_details = tbl_information$tbl_src_details,
@@ -252,7 +305,10 @@ create_agent <- function(tbl = NULL,
       end_fns = list(end_fns),
       embed_report = embed_report,
       reporting = NULL,
-      reporting_lang = reporting_lang,
+      lang = lang,
+      locale = locale,
+      time_start = as.POSIXct(NA)[-1],
+      time_end = as.POSIXct(NA)[-1],
       validation_set =
         dplyr::tibble(
           i = integer(0),
